pub enum DropPosition {
Before,
After,
Inside,
}Expand description
Specifies where a node should be placed relative to a target during drag-drop.
This enum is used in OutlinerActions::on_move to indicate the desired
position of the dragged node relative to the drop target.
Variants
Before
Place the node before the target (as a sibling)
After
Place the node after the target (as a sibling)
Inside
Place the node inside the target (as a child)
This is only valid if the target is a collection node.