IconType

Enum IconType 

pub enum IconType {
    Collection,
    Entity,
    Custom(String),
}
The type of icon to display next to a node.

This enum defines the built-in icon types that can be used for nodes. Custom icons can be added using the Custom variant.

Variants



Collection

Icon for collection nodes (nodes that can contain children)



Entity

Icon for entity nodes (leaf nodes)



Custom(String)

Custom icon with a user-defined identifier

The string can be used to look up custom icon rendering logic or to specify an icon from an external icon set.